@@ -47,13 +47,27 @@
 # repotype must be stable or dev
 repotype=dev
 
+# post-4.2.8:
+# version=Protocol.Minor (.Point is added later)
+# 4.2.8 and before:
 # version=Protocol.Major.Minor
 # odd minor numbers are for -dev, even minor numbers are for -stable
+#
+# ** new format only tracks the major number for output style
+# ** The minor number becomes the "release" number.
+#
 # UpdatePoint will fail if repotype is inconsistent with minor.
 proto=4
-major=2
-minor=7
-version=${proto}.${major}.${minor}
+major=4
+minor=3
+
+case "${proto}.${major}" in
+ 4.[012])
+    version=${proto}.${major}.${minor}
+    ;;
+ *) version=${proto}.${minor}
+    ;;
+esac
 
 # Special.  Normally unused.  A suffix.
 #special=ag
@@ -65,12 +79,15 @@ prerelease=
 # ChangeLog starting tag (see also CommitLog-4.1.0)
 CLTAG=NTP_4_2_0
 
+### post-4.2.8:
+### Point number, after "proto.minor.", normally modified by script.
+### 4.2.8 and before:
 ### Point number, after "p", normally modified by script.
 # 3 cases:
 # - Numeric values increment
-# - empty 'increments' to 1
+# - empty 'increments' to 0 for dev, 1 for stable
 # - NEW 'increments' to empty
-point=182
+point=0
 
 ### betapoint is normally modified by script.
 # ntp-stable Beta number (betapoint)
@@ -91,4 +108,4 @@ betapoint=0
 # - - prerelease is emptied
 # else (not in RC)
 # - rcpoint is empty and unused (for now).
-rcpoint=
+rcpoint=GRONK
